# Youtube-Zik
DDL music from Youtube with Python GUI(wxPython)V2

A project based on [pytubefix](https://github.com/JuanBindez/pytubefix) !

Thanks for their work !

# /!\ Very Important Update /!\ (13/02/2025)
Now you need [NodeJS](https://nodejs.org/en) installed on your machine to bypass YT PoToken security.

just download NodeJS via the link, install it on your machine and there's nothing more to do !


# Quickstart
Install from [youtube-zik Pypi](https://pypi.org/project/youtube-zik) with PIP :


	pip install youtube-zik
	
	
Once installed just use with this command:


	py -m youtube-zik


# Installation(to work on code)
Create a virtual env : [Python Venv Setup](https://mothergeo-py.readthedocs.io/en/latest/development/how-to/venv-win.html)

inside your Venv install requirements :


	pip install -r /path/to/requirements.txt


Use your favorite editor to code on Youtube-zik.py !
	
# Installation(Windows executable)
Download YoutubeDDL.rar

Use your favorite archiver(winrar,winzip,7z...)

Double click on YoutubeDDL.exe ! (just run it lol)

# Notice
Hello all !

Really simple to use :

	- "Collection" folders created on app launch if doesn't exist
	- Right click a BLUE music to download it
	- A RED music means that you already own it
	- You can't download twice the same music
	- "More Results" button to fecth more (actually 17 results)
	- Mp3/mp4 download format choice
	- You can enter a youtube URL directly to find your media !
	
That's all folks !

# Screenshot
![New release](http://ninjaaior.free.fr/Ytzik.png "Youtube-Zik DDL V2.2")

# Demo Vidéo
[![YT music & video Downloader](https://img.youtube.com/vi/rFFb_zwElYs/0.jpg)](https://www.youtube.com/watch?v=rFFb_zwElYs)

# Contact
fawn06220@gmail.com
